From: Eric Dumazet <eric.dumazet@gmail.com>
To: Raghavendra K T <raghavendra.kt@linux.vnet.ibm.com>
Cc: davem@davemloft.net, kuznet@ms2.inr.ac.ru, jmorris@namei.org,
yoshfuji@linux-ipv6.org, kaber@trash.net, jiri@resnulli.us,
edumazet@google.com, hannes@stressinduktion.org,
tom@herbertland.com, azhou@nicira.com, ebiederm@xmission.com,
ipm@chirality.org.uk, nicolas.dichtel@6wind.com,
serge.hallyn@canonical.com, joe@perches.com,
netdev@vger.kernel.org, linux-kernel@vger.kernel.org,
anton@au1.ibm.com, nacc@linux.vnet.ibm.com,
srikar@linux.vnet.ibm.com
Subject: Re: [PATCH RFC V4 2/2] net: Optimize snmp stat aggregation by walking all the percpu data at once
Date: Sun, 30 Aug 2015 08:52:09 -0700 [thread overview]
Message-ID: <1440949929.8932.150.camel@edumazet-glaptop2.roam.corp.google.com> (raw)
In-Reply-To: <1440914382-23126-3-git-send-email-raghavendra.kt@linux.vnet.ibm.com>
On Sun, 2015-08-30 at 11:29 +0530, Raghavendra K T wrote:
> Docker container creation linearly increased from around 1.6 sec to 7.5 sec
> (at 1000 containers) and perf data showed 50% ovehead in snmp_fold_field.
>
> reason: currently __snmp6_fill_stats64 calls snmp_fold_field that walks
> through per cpu data of an item (iteratively for around 36 items).
>
> idea: This patch tries to aggregate the statistics by going through
> all the items of each cpu sequentially which is reducing cache
> misses.
>
> Docker creation got faster by more than 2x after the patch.
>
> Result:
> Before After
> Docker creation time 6.836s 3.25s
> cache miss 2.7% 1.41%
>
> perf before:
> 50.73% docker [kernel.kallsyms] [k] snmp_fold_field
> 9.07% swapper [kernel.kallsyms] [k] snooze_loop
> 3.49% docker [kernel.kallsyms] [k] veth_stats_one
> 2.85% swapper [kernel.kallsyms] [k] _raw_spin_lock
>
> perf after:
> 10.57% docker docker [.] scanblock
> 8.37% swapper [kernel.kallsyms] [k] snooze_loop
> 6.91% docker [kernel.kallsyms] [k] snmp_get_cpu_field
> 6.67% docker [kernel.kallsyms] [k] veth_stats_one
>
> changes/ideas suggested:
> Using buffer in stack (Eric), Usage of memset (David), Using memcpy in
> place of unaligned_put (Joe).
>
> Signed-off-by: Raghavendra K T <raghavendra.kt@linux.vnet.ibm.com>
> ---
Acked-by: Eric Dumazet <edumazet@google.com>
Thanks.
next prev parent reply other threads:[~2015-08-30 15:52 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2015-08-30 5:59 [PATCH RFC V4 0/2] Optimize the snmp stat aggregation for large cpus Raghavendra K T
2015-08-30 5:59 ` [PATCH RFC V4 1/2] net: Introduce helper functions to get the per cpu data Raghavendra K T
2015-08-30 5:59 ` [PATCH RFC V4 2/2] net: Optimize snmp stat aggregation by walking all the percpu data at once Raghavendra K T
2015-08-30 15:52 ` Eric Dumazet [this message]
2015-08-31 4:49 ` [PATCH RFC V4 0/2] Optimize the snmp stat aggregation for large cpus David Miller
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1440949929.8932.150.camel@edumazet-glaptop2.roam.corp.google.com \
--to=eric.dumazet@gmail.com \
--cc=anton@au1.ibm.com \
--cc=azhou@nicira.com \
--cc=davem@davemloft.net \
--cc=ebiederm@xmission.com \
--cc=edumazet@google.com \
--cc=hannes@stressinduktion.org \
--cc=ipm@chirality.org.uk \
--cc=jiri@resnulli.us \
--cc=jmorris@namei.org \
--cc=joe@perches.com \
--cc=kaber@trash.net \
--cc=kuznet@ms2.inr.ac.ru \
--cc=linux-kernel@vger.kernel.org \
--cc=nacc@linux.vnet.ibm.com \
--cc=netdev@vger.kernel.org \
--cc=nicolas.dichtel@6wind.com \
--cc=raghavendra.kt@linux.vnet.ibm.com \
--cc=serge.hallyn@canonical.com \
--cc=srikar@linux.vnet.ibm.com \
--cc=tom@herbertland.com \
--cc=yoshfuji@linux-ipv6.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®